@@ -1,13 +1,13 @@
 <?php
 //============================================================+
 // File name   : tcpdf_fonts.php
-// Version     : 1.0.010
+// Version     : 1.0.013
 // Begin       : 2008-01-01
-// Last Update : 2013-11-10
+// Last Update : 2014-05-23
 // Author      : Nicola Asuni - Tecnick.com LTD - www.tecnick.com - info@tecnick.com
 // License     : GNU-LGPL v3 (http://www.gnu.org/copyleft/lesser.html)
 // -------------------------------------------------------------------
-// Copyright (C) 2008-2013 Nicola Asuni - Tecnick.com LTD
+// Copyright (C) 2008-2014 Nicola Asuni - Tecnick.com LTD
 //
 // This file is part of TCPDF software library.
 //
@@ -42,7 +42,7 @@
  * @class TCPDF_FONTS
  * Font methods for TCPDF library.
  * @package com.tecnick.tcpdf
- * @version 1.0.010
+ * @version 1.0.013
  * @author Nicola Asuni - info@tecnick.com
  */
 class TCPDF_FONTS {
@@ -792,6 +792,7 @@ class TCPDF_FONTS {
 			}
 			$fmetric['MissingWidth'] = $cw[0];
 			$fmetric['cw'] = '';
+			$fmetric['cbbox'] = '';
 			for ($cid = 0; $cid <= 65535; ++$cid) {
 				if (isset($ctg[$cid])) {
 					if (isset($cw[$ctg[$cid]])) {
@@ -799,17 +800,17 @@ class TCPDF_FONTS {
 					}
 					if ($addcbbox AND isset($indexToLoc[$ctg[$cid]])) {
 						$offset = ($table['glyf']['offset'] + $indexToLoc[$ctg[$cid]]);
-						$xMin = round(TCPDF_STATIC::_getFWORD($font, $offset + 2)) * $urk;
-						$yMin = round(TCPDF_STATIC::_getFWORD($font, $offset + 4)) * $urk;
-						$xMax = round(TCPDF_STATIC::_getFWORD($font, $offset + 6)) * $urk;
-						$yMax = round(TCPDF_STATIC::_getFWORD($font, $offset + 8)) * $urk;
+						$xMin = round(TCPDF_STATIC::_getFWORD($font, $offset + 2) * $urk);
+						$yMin = round(TCPDF_STATIC::_getFWORD($font, $offset + 4) * $urk);
+						$xMax = round(TCPDF_STATIC::_getFWORD($font, $offset + 6) * $urk);
+						$yMax = round(TCPDF_STATIC::_getFWORD($font, $offset + 8) * $urk);
 						$fmetric['cbbox'] .= ','.$cid.'=>array('.$xMin.','.$yMin.','.$xMax.','.$yMax.')';
 					}
 				}
 			}
 		} // end of true type
 		if (($fmetric['type'] == 'TrueTypeUnicode') AND (count($ctg) == 256)) {
-			$fmetric['type'] == 'TrueType';
+			$fmetric['type'] = 'TrueType';
 		}
 		// ---------- create php font file ----------
 		$pfile = '<'.'?'.'php'."\n";
@@ -896,7 +897,7 @@ class TCPDF_FONTS {
 		$pfile .= '\'MaxWidth\'=>'.$fmetric['MaxWidth'].',';
 		$pfile .= '\'MissingWidth\'=>'.$fmetric['MissingWidth'].'';
 		$pfile .= ');'."\n";
-		if (isset($fmetric['cbbox'])) {
+		if (!empty($fmetric['cbbox'])) {
 			$pfile .= '$cbbox=array('.substr($fmetric['cbbox'], 1).');'."\n";
 		}
 		$pfile .= '$cw=array('.substr($fmetric['cw'], 1).');'."\n";
@@ -1140,7 +1141,7 @@ class TCPDF_FONTS {
 								$subsetglyphs[$g] = true;
 							}
 						}
-					}
+					}	
 					break;
 				}
 				case 6: { // Format 6: Trimmed table mapping
@@ -1603,9 +1604,9 @@ class TCPDF_FONTS {
 	 */
 	public static function UTF8ArrayToUniArray($ta, $isunicode=true) {
 		if ($isunicode) {
-			return array_map(array('self', 'unichrUnicode'), $ta);
+			return array_map(array('TCPDF_FONTS', 'unichrUnicode'), $ta);
 		}
-		return array_map(array('self', 'unichrASCII'), $ta);
+		return array_map(array('TCPDF_FONTS', 'unichrASCII'), $ta);
 	}
 
 	/**
@@ -1882,7 +1883,7 @@ class TCPDF_FONTS {
 		if ($isunicode) {
 			// requires PCRE unicode support turned on
 			$chars = TCPDF_STATIC::pregSplit('//','u', $str, -1, PREG_SPLIT_NO_EMPTY);
-			$carr = array_map(array('self', 'uniord'), $chars);
+			$carr = array_map(array('TCPDF_FONTS', 'uniord'), $chars);
 		} else {
 			$chars = str_split($str);
 			$carr = array_map('ord', $chars);
